@@ -2,10 +2,12 @@ import secrets
 
 import pytest
 
+from hatch.utils.shells import detect_shell
+
 
 @pytest.fixture(autouse=True)
 def default_shells(platform):
-    return [] if platform.windows else ['sh']
+    return [] if platform.windows else [detect_shell(platform)[0]]
 
 
 @pytest.fixture(autouse=True)
