@@ -15,14 +15,14 @@ def get_files(**kwargs):
         if str(f.path) == 'LICENSE.txt':
             files.append(File(Path(metadata_directory, 'licenses', f.path), f.contents))
 
-        if f.path.parts[0] != kwargs['package_name']:
+        if f.path.parts[0] != 'src':
             continue
 
-        files.append(f)
+        files.append(File(Path(*f.path.parts[1:]), f.contents))
 
-    files.append(File(Path(kwargs['package_name'], 'lib.so'), ''))
-    files.append(File(Path('zlib.pyd'), ''))
-    files.append(
+    files.extend((
+        File(Path(kwargs['package_name'], 'lib.so'), ''),
+        File(Path('zlib.pyd'), ''),
         File(
             Path(metadata_directory, 'WHEEL'),
             f"""\
@@ -31,9 +31,7 @@ Generator: hatchling {__version__}
 Root-Is-Purelib: false
 Tag: {kwargs.get('tag', '')}
 """,
-        )
-    )
-    files.append(
+        ),
         File(
             Path(metadata_directory, 'METADATA'),
             f"""\
@@ -43,8 +41,8 @@ Version: 0.0.1
 License-File: LICENSE.txt
 Requires-Python: >3
 """,
-        )
-    )
+        ),
+    ))
 
     record_file = File(Path(metadata_directory, 'RECORD'), '')
     update_record_file_contents(record_file, files)
